@@ -1,29 +1,16 @@
 /**
  * Nested list helper
  *
- * Copyright 2008  Stephen Kelly <steveire@gmail.com>
+ * SPDX-FileCopyrightText: 2008 Stephen Kelly <steveire@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifndef NESTEDLISTHELPER_H
 #define NESTEDLISTHELPER_H
 
 //@cond PRIVATE
-
+#include <QObject>
 class QTextEdit;
 
 class QKeyEvent;
@@ -109,7 +96,7 @@ public:
      *
      * @return Whether the item can be indented.
      */
-    bool canIndent() const;
+    Q_REQUIRED_RESULT bool canIndent() const;
 
     /**
      * \brief Check whether the current item in the list may be dedented.
@@ -120,7 +107,7 @@ public:
      *
      * @return Whether the item can be dedented.
      */
-    bool canDedent() const;
+    Q_REQUIRED_RESULT bool canDedent() const;
 
 private:
     QTextCursor topOfSelection();
